@@ -1,15 +1,15 @@
 package Test::Mocha::Inspect;
 {
-  $Test::Mocha::Inspect::VERSION = '0.19';
+  $Test::Mocha::Inspect::VERSION = '0.20';
 }
 # ABSTRACT: Mock wrapper to inspect method calls
 
 use strict;
 use warnings;
 
-use Test::Mocha::MethodCall;
+use Test::Mocha::Method;
 use Test::Mocha::Types qw( Mock );
-use Test::Mocha::Util  qw( extract_method_name get_attribute_value );
+use Test::Mocha::Util  qw( extract_method_name getattr );
 
 our $AUTOLOAD;
 
@@ -23,13 +23,13 @@ sub new {
 sub AUTOLOAD {
     my $self = shift;
 
-    my $inspect = Test::Mocha::MethodCall->new(
+    my $inspect = Test::Mocha::Method->new(
         name => extract_method_name($AUTOLOAD),
         args => \@_,
     );
 
-    my $mock  = get_attribute_value($self, 'mock');
-    my $calls = get_attribute_value($mock, 'calls');
+    my $mock  = getattr($self, 'mock');
+    my $calls = getattr($mock, 'calls');
 
     return grep { $inspect->satisfied_by($_) } @$calls;
 }
